@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -35,8 +35,7 @@
 #include "gthumb-window.h"
 #include "gtk-utils.h"
 #include "gtkcellrendererthreestates.h"
-#include "image-list.h"
-#include "image-list-utils.h"
+#include "gth-file-view.h"
 #include "comments.h"
 
 
@@ -72,7 +71,7 @@ typedef struct {
 
 /* called when the main dialog is closed. */
 static void
-destroy_cb (GtkWidget *widget, 
+destroy_cb (GtkWidget  *widget, 
 	    DialogData *data)
 {
 	data->window->categories_dlg = NULL;
@@ -426,7 +425,6 @@ dlg_categories (GtkWidget *widget,
 {
 	GThumbWindow      *window = wdata;
 	DialogData        *data;
-	ImageList         *ilist;
 	GtkWidget         *btn_ok;
 	GtkWidget         *btn_cancel;
 	GtkWidget         *btn_help;
@@ -452,8 +450,7 @@ dlg_categories (GtkWidget *widget,
                 return;
         }
 
-	ilist = IMAGE_LIST (window->file_list->ilist);
-	data->file_list = ilist_utils_get_file_list_selection (ilist);
+	data->file_list = gth_file_view_get_file_list_selection (window->file_list->view);
 	if (data->file_list == NULL) {
 		g_free (data);
 		return;
